@@ -2,6 +2,8 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
+import copy
+import concurrent.futures
 from datetime import datetime
 import logging
 import re
@@ -279,7 +281,7 @@ class GbqConnector(object):
         project_id,
         reauth=False,
         private_key=None,
-        auth_local_webserver=False,
+        auth_local_webserver=True,
         dialect="standard",
         location=None,
         credentials=None,
@@ -378,6 +380,9 @@ class GbqConnector(object):
         # See `BigQuery Troubleshooting Errors
         # <https://cloud.google.com/bigquery/troubleshooting-errors>`__
 
+        if "cancelled" in ex.message:
+            raise QueryTimeout("Reason: {0}".format(ex))
+
         raise GenericGBQException("Reason: {0}".format(ex))
 
     def download_table(
@@ -406,8 +411,41 @@ class GbqConnector(object):
             user_dtypes=dtypes,
         )
 
+    def _wait_for_query_job(self, query_reply, timeout_ms):
+        """Wait for query to complete, pausing occasionally to update progress.
+
+        Args:
+            query_reply (QueryJob):
+                A query job which has started.
+
+            timeout_ms (Optional[int]):
+                How long to wait before cancelling the query.
+        """
+        # Wait at most 10 seconds so we can show progress.
+        # TODO(https://github.com/googleapis/python-bigquery-pandas/issues/327):
+        # Include a tqdm progress bar here instead of a stream of log messages.
+        timeout_sec = 10.0
+        if timeout_ms:
+            timeout_sec = min(timeout_sec, timeout_ms / 1000.0)
+
+        while query_reply.state != "DONE":
+            self.log_elapsed_seconds("  Elapsed", "s. Waiting...")
+
+            if timeout_ms and timeout_ms < self.get_elapsed_seconds() * 1000:
+                self.client.cancel_job(
+                    query_reply.job_id, location=query_reply.location
+                )
+                raise QueryTimeout("Query timeout: {} ms".format(timeout_ms))
+
+            try:
+                query_reply.result(timeout=timeout_sec)
+            except concurrent.futures.TimeoutError:
+                # Use our own timeout logic
+                pass
+            except self.http_error as ex:
+                self.process_http_error(ex)
+
     def run_query(self, query, max_results=None, progress_bar_type=None, **kwargs):
-        from concurrent.futures import TimeoutError
         from google.auth.exceptions import RefreshError
         from google.cloud import bigquery
         import pandas
@@ -449,28 +487,11 @@ class GbqConnector(object):
         job_id = query_reply.job_id
         logger.debug("Job ID: %s" % job_id)
 
-        while query_reply.state != "DONE":
-            self.log_elapsed_seconds("  Elapsed", "s. Waiting...")
-
-            timeout_ms = job_config.get("jobTimeoutMs") or job_config["query"].get(
-                "timeoutMs"
-            )
-            timeout_ms = int(timeout_ms) if timeout_ms else None
-            if timeout_ms and timeout_ms < self.get_elapsed_seconds() * 1000:
-                raise QueryTimeout("Query timeout: {} ms".format(timeout_ms))
-
-            timeout_sec = 1.0
-            if timeout_ms:
-                # Wait at most 1 second so we can show progress bar
-                timeout_sec = min(1.0, timeout_ms / 1000.0)
-
-            try:
-                query_reply.result(timeout=timeout_sec)
-            except TimeoutError:
-                # Use our own timeout logic
-                pass
-            except self.http_error as ex:
-                self.process_http_error(ex)
+        timeout_ms = job_config.get("jobTimeoutMs") or job_config["query"].get(
+            "timeoutMs"
+        )
+        timeout_ms = int(timeout_ms) if timeout_ms else None
+        self._wait_for_query_job(query_reply, timeout_ms)
 
         if query_reply.cache_hit:
             logger.debug("Query done.\nCache hit.\n")
@@ -673,13 +694,35 @@ def _finalize_dtypes(
     return df
 
 
+def _transform_read_gbq_configuration(configuration):
+    """
+    For backwards-compatibility, convert any previously client-side only
+    parameters such as timeoutMs to the property name expected by the REST API.
+
+    Makes a copy of configuration if changes are needed.
+    """
+
+    if configuration is None:
+        return None
+
+    timeout_ms = configuration.get("query", {}).get("timeoutMs")
+    if timeout_ms is not None:
+        # Transform timeoutMs to an actual server-side configuration.
+        # https://github.com/googleapis/python-bigquery-pandas/issues/479
+        configuration = copy.deepcopy(configuration)
+        del configuration["query"]["timeoutMs"]
+        configuration["jobTimeoutMs"] = timeout_ms
+
+    return configuration
+
+
 def read_gbq(
     query_or_table,
     project_id=None,
     index_col=None,
     col_order=None,
     reauth=False,
-    auth_local_webserver=False,
+    auth_local_webserver=True,
     dialect=None,
     location=None,
     configuration=None,
@@ -719,7 +762,7 @@ def read_gbq(
     reauth : boolean, default False
         Force Google BigQuery to re-authenticate the user. This is useful
         if multiple accounts are used.
-    auth_local_webserver : bool, default False
+    auth_local_webserver : bool, default True
         Use the `local webserver flow
         <https://googleapis.dev/python/google-auth-oauthlib/latest/reference/google_auth_oauthlib.flow.html#google_auth_oauthlib.flow.InstalledAppFlow.run_local_server>`_
         instead of the `console flow
@@ -847,6 +890,8 @@ def read_gbq(
     if dialect not in ("legacy", "standard"):
         raise ValueError("'{0}' is not valid for dialect".format(dialect))
 
+    configuration = _transform_read_gbq_configuration(configuration)
+
     if configuration and "query" in configuration and "query" in configuration["query"]:
         if query_or_table is not None:
             raise ValueError(
@@ -914,7 +959,7 @@ def to_gbq(
     chunksize=None,
     reauth=False,
     if_exists="fail",
-    auth_local_webserver=False,
+    auth_local_webserver=True,
     table_schema=None,
     location=None,
     progress_bar=True,
@@ -960,7 +1005,7 @@ def to_gbq(
             If table exists, drop it, recreate it, and insert data.
         ``'append'``
             If table exists, insert data. Create if does not exist.
-    auth_local_webserver : bool, default False
+    auth_local_webserver : bool, default True
         Use the `local webserver flow
         <https://googleapis.dev/python/google-auth-oauthlib/latest/reference/google_auth_oauthlib.flow.html#google_auth_oauthlib.flow.InstalledAppFlow.run_local_server>`_
         instead of the `console flow
